ResourceForkDetectionStrategy

Enum ResourceForkDetectionStrategy 

pub enum ResourceForkDetectionStrategy {
    All,
    None,
    HiddenDirectory,
    NamedFork,
    Suffix,
}
Strategy to detect resource fork on the disk

Since (most) modern file systems and operating systems don’t support resource forks, the resource data is often stored in a separate file.

There are several conventions. SheepShaver for example places the resource fork in a directory called .rsrc next to data fork. While resource_dasm choses to append .rsrc to the filename to store the resource fork.

MacOS is still capable of managing proper resource forks and uses special syntax (e.g. path/to/file.ext/..namedfork/rsrc) to access its contents.

Variants



All

Try each of the subsequent strategies until a resource fork is found



None

Don’t try to find any resource forks



HiddenDirectory

Look for a file with the same name in a directory called .rsrc



NamedFork

On macos, open the actual resource fork using the /..namedfork/rsrc syntax



Suffix

Look for a file with the same name and an additional extension called .rsrc