pub type Fork = Fork;
pub enum Fork { Resource, Data, }
Identifies the resource fork that stores data in a system defined structure
Identifies the data fork whose format is entirely up to the application creating it