pub type Error = Error;Aliased Type
pub enum Error {
BadMagic {
pos: u64,
found: Box<dyn Debug + Sync + Send>,
},
AssertFail {
pos: u64,
message: String,
},
Io(Error),
Custom {
pos: u64,
err: Box<dyn CustomError>,
},
NoVariantMatch {
pos: u64,
},
EnumErrors {
pos: u64,
variant_errors: Vec<(&'static str, Error)>,
},
Backtrace(Backtrace),
}Variants
BadMagic
An expected magic number was not found.
Fields
AssertFail
An assertion failed.
This variant is used for assert directives which use a string
literal instead of an error object. Assertions that use error objects
are represented by the Custom variant.
Fields
Io(Error)
An error occurred in the underlying reader while reading or seeking to data.
Custom
A user-generated error.
This variant is used for assert directives which use an error object
instead of a string literal. Assertions that use string literals are
represented by the AssertFail variant.
Fields
err: Box<dyn CustomError>The original error.
NoVariantMatch
None of the variants of an enum could successfully be parsed from the data in the reader.
This variant is used when the return_unexpected_error directive is
set on an enum.
EnumErrors
None of the variants of an enum could successfully be parsed from the data in the reader.
This variant is used when the return_all_errors directive is
set on an enum (which is the default).
Fields
Backtrace(Backtrace)
An error with additional frames of context used to construct a backtrace